@@ -9,7 +9,7 @@ Written by Eirik Berger
 class Book:
     """Class defining informatino and methods for printed books (pdfs)."""
 
-    def __init__(self, input_file, output_folder):
+    def __init__(self, input_file, output_folder, xLineMargin=0.25):
         import os
 
         self.input_file = input_file
@@ -20,6 +20,8 @@ class Book:
         self.inputdir = os.path.dirname(self.input_file)
         self.bookdir = self.output_folder
 
+        self.xLineMargin = xLineMargin
+
         print()
         print("Class defined for: ", self.input_file)
         print()
@@ -223,12 +225,12 @@ class Book:
         i = 0
 
         for line in lines:
-            temp1 = abs(line[0][1] - line[1][1])
-            temp2 = abs(line[0][0] - line[1][0])
+            temp1 = abs(line[0][1] - line[1][1])        # length
+            temp2 = abs(line[0][0] - line[1][0])        # tilt
             if (
                     temp2 < 70
-                    and ((line[0][0] + line[1][0]) / 2) > w2*0.25
-                    and ((line[0][0] + line[1][0]) / 2) < w2*0.75
+                    and ((line[0][0] + line[1][0]) / 2) > w2*self.xLineMargin
+                    and ((line[0][0] + line[1][0]) / 2) < w2*(1-self.xLineMargin)
             ):
                 x_split = (line[0][0] + line[1][0]) / 2
                 lines_df.loc[i] = [temp1] + [temp2] + [x_split] + \
@@ -608,7 +610,7 @@ class Book:
         ###
 
         # text['t'] = text['text'].astype(str).str[0:3]
-        text['t1'] = text['text'].str.contains(r'^[A-XÆØÅa-zæøå][a-zæøå]{2,}')
+        text['t1'] = text['text'].str.contains(r'^[A-ZÆØÅa-zæøå][a-zæøå]{2,}')
         text['t2'] = text['text'].str.contains(r'^[0-9 ]{3,}')
         text['t31'] = text['text'].str.contains(r'^[, ]{0,2}Pn[r]{0,1} [0-9]')
         text['t32'] = text['text'].str.contains(r'^[, ]{0,2}P[n]{0,1}r [0-9]')
@@ -703,6 +705,8 @@ class Book:
                 text.at[i, 'DUMMY'] = 1
             if re.search("^—[ ]{0,1}[0-9]{3,}$", str(text.at[i+1, "text"])):
                 text.at[i, 'DUMMY'] = 1
+            if re.search("[^0-9]{3,}[0-9]{3,}$", str(text.at[i, "text"])) and re.search("^[0-9]{3,}$", str(text.at[i+1, "text"])):
+                text.at[i, 'DUMMY'] = 1
             if text.at[i, "page"] != text.at[i+1, "page"]:
                 text.at[i, 'DUMMY'] = 0
 
@@ -1028,9 +1032,9 @@ class Book:
         global csv
 
         csv = df.copy()
-        csv["text"] = csv["text"].str.replace(r"([0-9]{3,}) [a-zæøå]$", "\\1", regex=True)
+        csv["text"] = csv["text"].str.replace(r"([0-9]{3,}) [a-zøå]$", "\\1", regex=True)
 
-        extract = csv['text'].str.extract(r"^(.*?) ([a-xæøåäö., —]{3,})[ ]*([A-ZÆØÅÄÖ]{0,1}[^0-9]*?)([0-9]*)[—\- ]{1,3}([0-9]{1,})$")
+        extract = csv['text'].str.extract(r"^(.*?) ([a-zæøåäö., —]{3,})[ ]*([A-ZÆØÅÄÖ]{0,1}[^0-9]*?)([0-9]*)[—\- ]{1,3}([0-9]*)$")
         extract = extract.rename(columns={"0": "name",
                                           "1": "occupation",
                                           "2": "residence",
